@@ -14,3 +14,22 @@
 # Portions created by CWI are Copyright (C) 1997-July 2008 CWI.
 # Copyright August 2008-2012 MonetDB B.V.
 # All Rights Reserved.
+"""
+This is the MonetDB Python API.
+
+The MAPI (MonetDB API) related code is in monetdb.mapi.
+
+The SQL related code is in monetdb.sql.
+
+To set up a connection use monetdb.sql.connect()
+
+"""
+from monetdb import sql
+from monetdb import mapi
+from monetdb import exceptions
+
+__all__ = ["sql", "mapi"]
+
+# for backwards compatability
+monetdb_exceptions = exceptions
+
